@@ -37,7 +37,9 @@
 #'   non-circular marker is desired.
 #' @param ... Other arguments for the plotting function (e.g. `period` for
 #'   [openair::polarAnnulus()]).
-#' @return A leaflet object.
+#' @returns A leaflet object.
+#' @seealso `shiny::runExample(package = "openairmaps")` to see examples of this
+#'   function used in a [shiny::shinyApp()]
 #' @describeIn addPolarMarkers Add any one-table polar marker (e.g.,
 #'   [openair::polarPlot()])
 #' @export
@@ -150,7 +152,9 @@ addPolarMarkers <-
         iconHeight = height,
         iconWidth = width,
         iconAnchorX = width / 2,
-        iconAnchorY = height / 2
+        iconAnchorY = height / 2,
+        popupAnchorX = -.Machine$double.eps,
+        popupAnchorY = -(height / 2) * 0.7
       ),
       group = group,
       layerId = layerId,
@@ -268,7 +272,9 @@ addPolarDiffMarkers <-
         iconHeight = height,
         iconWidth = width,
         iconAnchorX = width / 2,
-        iconAnchorY = height / 2
+        iconAnchorY = height / 2,
+        popupAnchorX = -.Machine$double.eps,
+        popupAnchorY = -(height / 2) * 0.7
       ),
       group = group,
       layerId = layerId,
